@@ -14,10 +14,12 @@ from enum import IntEnum
 from enum import unique
 from functools import total_ordering
 
+from gi.repository import GdkPixbuf
 from gi.repository import Gio
 from nbxmpp.const import PresenceShow
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import JID
+from PIL import Image
 
 from gajim.common.i18n import _
 from gajim.common.i18n import p_
@@ -25,7 +27,7 @@ from gajim.common.i18n import p_
 STOP_EVENT = True
 PROPAGATE_EVENT = False
 
-MAX_MESSAGE_CORRECTION_DELAY = 300
+MAX_MESSAGE_CORRECTION_DELAY = 3600
 
 
 class EncryptionInfoMsg(Enum):
@@ -65,6 +67,7 @@ class AvatarSize(IntEnum):
     WORKSPACE = 36
     WORKSPACE_EDIT = 100
     CHAT = 48
+    CHAT_BANNER = 40
     MESSAGE_REPLY = 24
     NOTIFICATION = 96
     CALL = 100
@@ -106,7 +109,6 @@ class StyleAttr(Enum):
 
 @unique
 class CSSPriority(IntEnum):
-    PRE_THEME = 199
     APPLICATION = 600
     APPLICATION_DARK = 601
     DEFAULT_THEME = 610
@@ -311,25 +313,6 @@ class Draft:
     reply_pk: int | None
 
 
-MUC_CREATION_EXAMPLES = [
-    (p_('Group chat name', 'Team'),
-     p_('Group chat description', 'Project discussion'),
-     p_('Group chat address', 'team')),
-    (p_('Group chat name', 'Family'),
-     p_('Group chat description', 'Spring gathering'),
-     p_('Group chat address', 'family')),
-    (p_('Group chat name', 'Vacation'),
-     p_('Group chat description', 'Trip planning'),
-     p_('Group chat address', 'vacation')),
-    (p_('Group chat name', 'Repairs'),
-     p_('Group chat description', 'Local help group'),
-     p_('Group chat address', 'repairs')),
-    (p_('Group chat name', 'News'),
-     p_('Group chat description', 'Local news and reports'),
-     p_('Group chat address', 'news')),
-]
-
-
 MUC_DISCO_ERRORS = {
     'remote-server-not-found': _('Remote server not found'),
     'remote-server-timeout': _('Remote server timeout'),
@@ -919,7 +902,7 @@ NONREGISTERED_URI_SCHEMES = {
 # This is an excerpt of Media Types from
 # https://www.iana.org/assignments/media-types/media-types.xhtml
 # plus some additions
-MIME_TYPES = (
+OTHER_MIME_TYPES = {
     # application/
     'application/calendar+json',
     'application/calendar+xml',
@@ -927,7 +910,6 @@ MIME_TYPES = (
     'application/json',
     'application/mp4',
     'application/msword',
-    'application/octet-stream',
     'application/ogg',
     'application/pdf',
     'application/pgp-encrypted',
@@ -964,7 +946,23 @@ MIME_TYPES = (
     # End office
     'application/vnd.sqlite3',
     'application/zip',
-    # audio/*
+    # font/*
+    'font/ttf',
+    'font/woff',
+    'font/woff2',
+    # model/*
+    'model/mtl',
+    'model/obj',
+    'model/stl',
+    # text/*
+    'text/calendar',
+    'text/csv',
+    'text/markdown',
+    'text/rtf',
+    'text/vcard',
+}
+
+AUDIO_MIME_TYPES = {
     'audio/aac',
     'audio/ac3',
     'audio/flac',
@@ -984,41 +982,9 @@ MIME_TYPES = (
     'audio/x-mpeg',
     'audio/x-ogg',
     'audio/x-wav',
-    # font/*
-    'font/ttf',
-    'font/woff',
-    'font/woff2',
-    # image/*
-    'image/webp',
-    'image/avif',
-    'image/jxl',
-    'image/bmp',
-    'image/x-bmp',
-    'image/x-ms-bmp',
-    'image/gif',
-    'image/heic',
-    'image/heif',
-    'image/jpeg',
-    'image/png',
-    'image/svg+xml',
-    'image/tiff',
-    'image/vnd.adobe.photoshop',
-    'image/vnd.dwg',
-    'image/vnd.dxf',
-    'image/vnd.microsoft.icon',
-    'image/x-icon',
-    'image/x-xcf',
-    # model/*
-    'model/mtl',
-    'model/obj',
-    'model/stl',
-    # text/*
-    'text/calendar',
-    'text/csv',
-    'text/markdown',
-    'text/rtf',
-    'text/vcard',
-    # video/*
+}
+
+VIDEO_MIME_TYPES = {
     'video/H264',
     'video/H265',
     'video/mp4',
@@ -1030,9 +996,46 @@ MIME_TYPES = (
     'video/webm',
     'video/x-matroska',
     'video/x-msvideo',
-)
+}
 
 
+def get_pixbuf_mime_types() -> set[str]:
+    pixbuf_mime_types: set[str] = set()
+
+    for fmt in GdkPixbuf.Pixbuf.get_formats():
+        mime_types = fmt.get_mime_types()
+        if mime_types is None:
+            continue
+        for mime_type in mime_types:
+            pixbuf_mime_types.add(mime_type.lower())
+
+    return pixbuf_mime_types
+
+
+def get_pil_mime_types() -> set[str]:
+    pil_mime_types: set[str] = set()
+
+    Image.init()
+    for mime_type in Image.MIME.values():
+        pil_mime_types.add(mime_type.lower())
+
+    return set(filter(
+        lambda mime_type: mime_type.startswith('image'),
+        pil_mime_types
+    ))
+
+
+PIL_IMAGE_MIME_TYPES = get_pil_mime_types()
+PIXBUF_IMAGE_MIME_TYPES = get_pixbuf_mime_types()
+IMAGE_MIME_TYPES = PIL_IMAGE_MIME_TYPES | PIXBUF_IMAGE_MIME_TYPES
+
+ALL_MIME_TYPES = (
+    OTHER_MIME_TYPES |
+    IMAGE_MIME_TYPES |
+    AUDIO_MIME_TYPES |
+    VIDEO_MIME_TYPES
+)
+
 TRUST_SYMBOL_DATA = {
     Trust.UNTRUSTED: ('lucide-circle-x-symbolic',
                       _('Untrusted'),
