@@ -80,7 +80,7 @@ def sanitize_filename(filename: str) -> str:
     Limit filename length to 50 chars on all systems
     '''
     if sys.platform == 'win32':
-        blacklist = ['\\', '/', ':', '*', '?', '"', '<', '>', '|', '\0']
+        blacklist = ['\\', '/', ':', '*', '?', '？', '"', '<', '>', '|', '\0']
         reserved_filenames = [
             'CON', 'PRN', 'AUX', 'NUL', 'COM1', 'COM2', 'COM3', 'COM4', 'COM5',
             'COM6', 'COM7', 'COM8', 'COM9', 'LPT1', 'LPT2', 'LPT3', 'LPT4',
@@ -111,18 +111,6 @@ def sanitize_filename(filename: str) -> str:
     return f'{filename}{extension}'
 
 
-def get_contact_dict_for_account(account: str) -> dict[str, types.BareContact]:
-    '''
-    Creates a dict of jid -> contact with all contacts of account
-    Can be used for completion lists
-    '''
-    contacts_dict: dict[str, types.BareContact] = {}
-    client = app.get_client(account)
-    for contact in client.get_module('Roster').iter_contacts():
-        contacts_dict[str(contact.jid)] = contact
-    return contacts_dict
-
-
 def generate_qr_code(content: str) -> Gdk.Texture:
     qr = qrcode.QRCode(version=None,
                        error_correction=qrcode.constants.ERROR_CORRECT_L,
@@ -281,15 +269,18 @@ def get_proxy(proxy_name: str) -> ProxyData | None:
                      password=password)
 
 
-def determine_proxy() -> ProxyData | None:
-    # Use this method to find a proxy for non-account related http requests
-    # When there is no global proxy and at least one active account does
-    # not use a proxy, we assume no proxy is necessary.
+def determine_proxy(account: str | None = None) -> ProxyData | None:
+
+    if account is not None:
+        return get_account_proxy(account)
 
     global_proxy = get_global_proxy()
     if global_proxy is not None:
         return global_proxy
 
+    # When there is no global proxy and at least one active account does
+    # not use a proxy, we assume no proxy is necessary.
+
     proxies: list[ProxyData] = []
     for client in app.get_clients():
         account_proxy = get_account_proxy(client.account, fallback=False)
@@ -562,3 +553,11 @@ def warn_about_plain_connection(account: str,
 
 def get_uuid() -> str:
     return str(uuid.uuid4())
+
+
+def idle_add_once(func: Callable[..., Any], *args: Any) -> None:
+    def wrapper():
+        func(*args)
+        return False
+
+    GLib.idle_add(wrapper)
