@@ -22,11 +22,11 @@ from gajim.common import app
 from gajim.common.util.version import package_version
 
 __all__ = [
+    'delete_password',
+    'get_password',
     'init',
     'is_keyring_available',
-    'get_password',
-    'save_password',
-    'delete_password'
+    'save_password'
 ]
 
 log = logging.getLogger('gajim.c.passwords')
@@ -131,6 +131,8 @@ class SecretPasswordStorage:
             _interface.backend.delete_password('gajim', account_name)
         except keyring_errors:
             pass
+        except Exception:
+            pass
 
         try:
             return _interface.backend.delete_password('gajim', account_jid)
