@@ -54,6 +54,7 @@ from gajim.common.storage.archive.models import Message
 from gajim.common.storage.archive.models import MessageError
 from gajim.common.storage.archive.models import Moderation
 from gajim.common.storage.archive.models import Occupant
+from gajim.common.storage.archive.models import OpenGraph
 from gajim.common.storage.archive.models import Reaction
 from gajim.common.storage.archive.models import Receipt
 from gajim.common.storage.archive.models import Remote
@@ -69,7 +70,7 @@ from gajim.common.util.datetime import FIRST_UTC_DATETIME
 from gajim.common.util.datetime import utc_now
 from gajim.common.util.text import get_random_string
 
-CURRENT_USER_VERSION = 15
+CURRENT_USER_VERSION = 16
 
 
 log = logging.getLogger("gajim.c.storage.archive")
@@ -220,7 +221,6 @@ class MessageArchiveStorage(AlchemyStorage):
     def insert_object(
         self, session: Session, obj: Any, ignore_on_conflict: bool = True
     ) -> int:
-
         obj.validate()
         self._set_foreign_keys(session, obj)
         self._log_row(obj)
@@ -260,7 +260,6 @@ class MessageArchiveStorage(AlchemyStorage):
         return_pk_on_conflict: bool = False,
         ignore_on_conflict: bool = False,
     ) -> int:
-
         row.validate()
         self._set_foreign_keys(session, row)
         self._log_row(row)
@@ -292,7 +291,6 @@ class MessageArchiveStorage(AlchemyStorage):
         session: Session,
         row: Any,
     ) -> int:
-
         row.validate()
         self._set_foreign_keys(session, row)
         self._log_row(row)
@@ -329,7 +327,6 @@ class MessageArchiveStorage(AlchemyStorage):
         session: Session,
         row: Any,
     ) -> int | None:
-
         row.validate()
         self._set_foreign_keys(session, row)
         self._log_row(row)
@@ -364,7 +361,6 @@ class MessageArchiveStorage(AlchemyStorage):
     def get_message_with_id(
         self, session: Session, account: str, jid: JID, message_id: str
     ) -> Message | None:
-
         fk_account_pk = self._get_account_pk(session, account)
         fk_remote_pk = self._get_jid_pk(session, jid)
 
@@ -388,7 +384,6 @@ class MessageArchiveStorage(AlchemyStorage):
     def get_message_with_stanza_id(
         self, session: Session, account: str, jid: JID, stanza_id: str
     ) -> Message | None:
-
         fk_account_pk = self._get_account_pk(session, account)
         fk_remote_pk = self._get_jid_pk(session, jid)
 
@@ -736,7 +731,6 @@ class MessageArchiveStorage(AlchemyStorage):
     def get_referenced_message(
         self, account: str, jid: JID, message_type: MessageType | int, reply_id: str
     ) -> Message | None:
-
         if message_type == MessageType.GROUPCHAT:
             return app.storage.archive.get_message_with_stanza_id(
                 account, jid, reply_id
@@ -761,7 +755,6 @@ class MessageArchiveStorage(AlchemyStorage):
     def get_last_display_marker(
         self, session: Session, account: str, jid: JID
     ) -> DisplayedMarker | None:
-
         fk_account_pk = self._get_account_pk(session, account)
         fk_remote_pk = self._get_jid_pk(session, jid)
 
@@ -784,7 +777,6 @@ class MessageArchiveStorage(AlchemyStorage):
     def get_last_display_markers(
         self, session: Session, account: str, jid: JID
     ) -> list[DisplayedMarker]:
-
         fk_account_pk = self._get_account_pk(session, account)
         fk_remote_pk = self._get_jid_pk(session, jid)
 
@@ -1207,6 +1199,10 @@ class MessageArchiveStorage(AlchemyStorage):
 
         self._account_pks.pop(account)
 
+    @with_session
+    def remove_og(self, session: Session, pk: int) -> None:
+        session.execute(delete(OpenGraph).where(OpenGraph.pk == pk))
+
     @with_session
     @timeit
     def cleanup_chat_history(self, session: Session) -> None:
