@@ -47,10 +47,10 @@ from sqlalchemy.orm import sessionmaker
 
 from gajim.common.util.version import python_version
 
-log = logging.getLogger('gajim.c.storage')
+log = logging.getLogger("gajim.c.storage")
 
-P = ParamSpec('P')
-R = TypeVar('R')
+P = ParamSpec("P")
+R = TypeVar("R")
 
 
 class ValueMissingT:
@@ -68,14 +68,14 @@ def timeit(func: Callable[P, R]) -> Callable[P, R]:
         start = time.time()
         result = func(*args, **kwargs)
         exec_time = (time.time() - start) * 1e3
-        log.debug('Execution time for %s: %s ms', func.__name__, math.ceil(exec_time))
+        log.debug("Execution time for %s: %s ms", func.__name__, math.ceil(exec_time))
         return result
 
     return func_wrapper
 
 
 def with_session(
-    func: Callable[Concatenate[Any, Session, P], R]
+    func: Callable[Concatenate[Any, Session, P], R],
 ) -> Callable[Concatenate[Any, P], R]:
     def wrapper(self: Any, *args: P.args, **kwargs: P.kwargs) -> R:
         with self._create_session() as session, session.begin():
@@ -85,7 +85,7 @@ def with_session(
 
 
 def with_session_yield_from(
-    func: Callable[Concatenate[Any, Session, P], Iterator[R]]
+    func: Callable[Concatenate[Any, Session, P], Iterator[R]],
 ) -> Callable[Concatenate[Any, P], Iterator[Any]]:
     def wrapper(self: Any, *args: P.args, **kwargs: P.kwargs) -> Iterator[R]:
         with self._create_session() as session, session.begin():
@@ -102,15 +102,15 @@ def _adapt_common_error(common_error: CommonError) -> str:
     return common_error.serialize()
 
 
-sqlite3.register_converter('common_error', _convert_common_error)
+sqlite3.register_converter("common_error", _convert_common_error)
 sqlite3.register_adapter(CommonError, _adapt_common_error)
 
 
 def _convert_marker(marker: bytes):
-    return 'received' if int(marker) == 0 else 'displayed'
+    return "received" if int(marker) == 0 else "displayed"
 
 
-sqlite3.register_converter('marker', _convert_marker)
+sqlite3.register_converter("marker", _convert_marker)
 
 
 def _jid_adapter(jid: JID) -> str:
@@ -121,7 +121,7 @@ def _jid_converter(jid: bytes) -> JID:
     return JID.from_string(jid.decode())
 
 
-sqlite3.register_converter('jid', _jid_converter)
+sqlite3.register_converter("jid", _jid_converter)
 sqlite3.register_adapter(JID, _jid_adapter)
 
 
@@ -133,7 +133,7 @@ def _adapt_disco_info(disco_info: DiscoInfo) -> str:
     return str(disco_info.stanza)
 
 
-sqlite3.register_converter('disco_info', _convert_disco_info)
+sqlite3.register_converter("disco_info", _convert_disco_info)
 sqlite3.register_adapter(DiscoInfo, _adapt_disco_info)
 
 
@@ -141,14 +141,14 @@ def _convert_json(json_string: bytes) -> dict[str, Any]:
     return json.loads(json_string, object_hook=json_decoder)
 
 
-sqlite3.register_converter('JSON', _convert_json)
+sqlite3.register_converter("JSON", _convert_json)
 
 
 def _datetime_converter(data: bytes) -> datetime:
     return datetime.fromisoformat(data.decode())
 
 
-sqlite3.register_converter('datetime', _datetime_converter)
+sqlite3.register_converter("datetime", _datetime_converter)
 
 
 sqlite3.register_adapter(ValueMissingT, lambda _val: None)
@@ -160,53 +160,53 @@ class Encoder(json.JSONEncoder):
             return list(o)  # pyright: ignore
 
         if isinstance(o, datetime):
-            return {'__type': 'datetime', 'value': o.isoformat()}
+            return {"__type": "datetime", "value": o.isoformat()}
 
         if isinstance(o, JID):
-            return {'__type': 'JID', 'value': str(o)}
+            return {"__type": "JID", "value": str(o)}
 
         if isinstance(o, RosterItem):
             dct = o.asdict()
-            dct['__type'] = 'RosterItem'
+            dct["__type"] = "RosterItem"
             return dct
 
         if isinstance(o, Affiliation | Role | StatusCode):
-            return {'value': o.value, '__type': o.__class__.__name__}
+            return {"value": o.value, "__type": o.__class__.__name__}
 
         return json.JSONEncoder.default(self, o)
 
 
 def json_decoder(dct: dict[str, Any]) -> Any:
-    type_ = dct.get('__type')
+    type_ = dct.get("__type")
     if type_ is None:
         return dct
 
-    if type_ == 'JID':
-        return JID.from_string(dct['value'])
+    if type_ == "JID":
+        return JID.from_string(dct["value"])
 
     if type_ == "datetime":
-        return datetime.fromisoformat(dct['value'])
+        return datetime.fromisoformat(dct["value"])
 
-    if type_ == 'RosterItem':
+    if type_ == "RosterItem":
         return RosterItem(
-            jid=dct['jid'],
-            name=dct['name'],
-            ask=dct['ask'],
-            subscription=dct['subscription'],
-            approved=dct['approved'],
-            groups=set(dct['groups']),
+            jid=dct["jid"],
+            name=dct["name"],
+            ask=dct["ask"],
+            subscription=dct["subscription"],
+            approved=dct["approved"],
+            groups=set(dct["groups"]),
         )
 
-    if type_ in ('Affiliation', 'Role', 'StatusCode'):
-        return getattr(nbxmpp.const, type_)(dct['value'])
+    if type_ in ("Affiliation", "Role", "StatusCode"):
+        return getattr(nbxmpp.const, type_)(dct["value"])
 
     return dct
 
 
 class SqliteStorage:
-    '''
+    """
     Base Storage Class
-    '''
+    """
 
     def __init__(
         self,
@@ -228,7 +228,7 @@ class SqliteStorage:
 
         else:
             if not self._path.is_file():
-                sys.exit('%s must be a file' % self._path)
+                sys.exit("%s must be a file" % self._path)
             self._con = self._connect(**kwargs)
 
         self._migrate_storage()
@@ -238,31 +238,31 @@ class SqliteStorage:
         return self._con
 
     def _enable_foreign_keys(self) -> None:
-        self._con.execute('PRAGMA foreign_keys=ON')
+        self._con.execute("PRAGMA foreign_keys=ON")
 
     def _set_journal_mode(self, mode: str) -> None:
-        self._con.execute(f'PRAGMA journal_mode={mode}')
+        self._con.execute(f"PRAGMA journal_mode={mode}")
 
     def _set_synchronous(self, mode: str) -> None:
-        self._con.execute(f'PRAGMA synchronous={mode}')
+        self._con.execute(f"PRAGMA synchronous={mode}")
 
     def _enable_secure_delete(self) -> None:
-        self._con.execute('PRAGMA secure_delete=1')
+        self._con.execute("PRAGMA secure_delete=1")
 
     def _run_analyze(self) -> None:
-        self._con.execute('PRAGMA analysis_limit=400')
-        self._con.execute('PRAGMA optimize')
+        self._con.execute("PRAGMA analysis_limit=400")
+        self._con.execute("PRAGMA optimize")
 
     @property
     def user_version(self) -> int:
-        return self._con.execute('PRAGMA user_version').fetchone()[0]
+        return self._con.execute("PRAGMA user_version").fetchone()[0]
 
     def _connect(self, **kwargs: Any) -> sqlite3.Connection:
-        self._log.info('Connect to %s', self._path)
-        return sqlite3.connect(self._path or ':memory:', **kwargs)
+        self._log.info("Connect to %s", self._path)
+        return sqlite3.connect(self._path or ":memory:", **kwargs)
 
     def _create_storage(self, **kwargs: Any) -> sqlite3.Connection:
-        self._log.info('Creating %s', self._path or 'in memory')
+        self._log.info("Creating %s", self._path or "in memory")
 
         con = self._connect(**kwargs)
 
@@ -272,11 +272,11 @@ class SqliteStorage:
         try:
             con.executescript(self._create_statement)
         except Exception:
-            self._log.exception('Error')
+            self._log.exception("Error")
             con.close()
             if self._path is not None:
                 self._path.unlink()
-            sys.exit('Failed creating storage')
+            sys.exit("Failed creating storage")
 
         con.commit()
         return con
@@ -292,27 +292,27 @@ class SqliteStorage:
             self._migrate()
         except Exception:
             self._con.close()
-            self._log.exception('Error')
+            self._log.exception("Error")
             sys.exit()
 
     def _migrate(self) -> None:
         raise NotImplementedError
 
     def _execute_multiple(self, statements: list[str]) -> None:
-        '''
+        """
         Execute multiple statements with the option to fail on duplicates
         but still continue
-        '''
+        """
         for sql in statements:
             try:
                 self._con.execute(sql)
                 self._con.commit()
             except sqlite3.OperationalError as error:
-                if str(error).startswith('duplicate column name:'):
+                if str(error).startswith("duplicate column name:"):
                     self._log.info(error)
                 else:
                     self._con.close()
-                    self._log.exception('Error')
+                    self._log.exception("Error")
                     sys.exit()
 
     @timeit
@@ -356,7 +356,7 @@ class AlchemyStorage:
             self._create_storage()
 
         elif not self._path.is_file():
-            sys.exit('%s must be a file' % self._path)
+            sys.exit("%s must be a file" % self._path)
 
         self._migrate_storage()
 
@@ -370,10 +370,10 @@ class AlchemyStorage:
         self, dbapi_connection: DBAPIConnection, _connection_record: Any
     ) -> None:
         cursor = dbapi_connection.cursor()
-        cursor.execute('PRAGMA foreign_keys=ON')
+        cursor.execute("PRAGMA foreign_keys=ON")
 
         for key, value in self._pragma.items():
-            cursor.execute(f'PRAGMA {key}={value}')
+            cursor.execute(f"PRAGMA {key}={value}")
         cursor.close()
 
     def _run_analyze(self) -> None:
@@ -381,27 +381,27 @@ class AlchemyStorage:
             connection = s.connection().connection.dbapi_connection
             assert connection is not None
             cursor = connection.cursor()
-            cursor.execute('PRAGMA analysis_limit=400')
-            cursor.execute('PRAGMA optimize')
-            cursor.execute('VACUUM')
+            cursor.execute("PRAGMA analysis_limit=400")
+            cursor.execute("PRAGMA optimize")
+            cursor.execute("VACUUM")
 
     def _get_user_version(self) -> int:
         with self._session as s:
-            return s.scalar(sa.text('PRAGMA user_version'))
+            return s.scalar(sa.text("PRAGMA user_version"))
 
     def _create_engine(self) -> Engine:
-        self._log.info('Create engine')
+        self._log.info("Create engine")
 
-        con_str = 'sqlite://'
+        con_str = "sqlite://"
         if self._path is not None:
-            con_str += f'/{self._path}'
+            con_str += f"/{self._path}"
 
         engine = sa.create_engine(
-            con_str, connect_args={'check_same_thread': False}, echo=False
+            con_str, connect_args={"check_same_thread": False}, echo=False
         )
-        event.listen(engine, 'connect', self._set_sqlite_pragma)
-        if os.environ.get('GAJIM_DEBUG_SQL'):
-            event.listen(Session, 'do_orm_execute', self._do_orm_execute)
+        event.listen(engine, "connect", self._set_sqlite_pragma)
+        if os.environ.get("GAJIM_DEBUG_SQL"):
+            event.listen(Session, "do_orm_execute", self._do_orm_execute)
         return engine
 
     def _do_orm_execute(self, orm_execute_state: ORMExecuteState) -> None:
@@ -413,16 +413,16 @@ class AlchemyStorage:
         )()
 
     def _create_storage(self) -> None:
-        self._log.info('Creating %s', self._path or 'in memory')
+        self._log.info("Creating %s", self._path or "in memory")
 
         with self._session as s:
             try:
                 self._create_table(s, self._engine)
             except Exception:
-                self._log.exception('Error')
+                self._log.exception("Error")
                 if self._path is not None:
                     self._path.unlink()
-                sys.exit('Failed creating storage')
+                sys.exit("Failed creating storage")
 
         if self._path is not None:
             self._path.chmod(0o600)
@@ -442,23 +442,23 @@ class AlchemyStorage:
         try:
             self._migrate()
         except Exception:
-            self._log.exception('Migration error')
+            self._log.exception("Migration error")
             raise
 
     def _migrate(self) -> None:
         raise NotImplementedError
 
     def _explain(self, session: Session, stmt: Any) -> None:
-        if not os.environ.get('GAJIM_DEBUG_SQL'):
+        if not os.environ.get("GAJIM_DEBUG_SQL"):
             return
 
         stmt = stmt.compile(
-            compile_kwargs={'literal_binds': True}, dialect=sqlite_dialect()
+            compile_kwargs={"literal_binds": True}, dialect=sqlite_dialect()
         )
 
-        res = session.execute(sa.text(f'EXPLAIN QUERY PLAN {stmt}')).all()
+        res = session.execute(sa.text(f"EXPLAIN QUERY PLAN {stmt}")).all()
         explanation = pprint.pformat(res)
-        log.debug('\n%s\n%s', stmt, explanation)
+        log.debug("\n%s\n%s", stmt, explanation)
 
     @with_session
     @timeit
@@ -511,7 +511,7 @@ class EpochTimestampType(sa.types.TypeDecorator[Any]):
             return None
 
         if value.tzinfo != UTC:
-            raise ValueError('DateTime must be UTC')
+            raise ValueError("DateTime must be UTC")
         return value.timestamp()
 
     def process_result_value(
@@ -541,8 +541,8 @@ def is_unique_constraint_error(error: sqlalchemy.exc.DatabaseError) -> bool:
     if not isinstance(error, sqlalchemy.exc.IntegrityError):
         return False
 
-    if python_version('<3.11'):
-        return 'UNIQUE constraint failed' in error.args[0]
+    if python_version("<3.11"):
+        return "UNIQUE constraint failed" in error.args[0]
     return (
         error.orig.sqlite_errorcode  # pyright: ignore
         == sqlite3.SQLITE_CONSTRAINT_UNIQUE
