@@ -19,12 +19,14 @@ from gi.repository import Pango
 from gi.repository import PangoCairo
 from nbxmpp.protocol import JID
 
+import gajim.common.storage.archive.models as mod
 from gajim.common import app
 from gajim.common import configpaths
 from gajim.common import types
 from gajim.common.const import AvatarSize
 from gajim.common.const import StyleAttr
 from gajim.common.modules.contacts import BareContact
+from gajim.common.modules.contacts import ResourceContact
 from gajim.common.util.classes import Singleton
 from gajim.common.util.image import get_pixbuf_from_file
 from gajim.common.util.image import scale_with_ratio
@@ -42,6 +44,7 @@ from gajim.gtk.util.styling import get_contact_color
 from gajim.gtk.util.styling import get_css_show_class
 from gajim.gtk.util.styling import make_rgba
 from gajim.gtk.util.styling import rgba_to_float
+from gajim.gtk.util.styling import text_to_color
 
 log = logging.getLogger("gajim.gtk.avatar")
 
@@ -49,6 +52,7 @@ log = logging.getLogger("gajim.gtk.avatar")
 AvatarCacheT = dict[
     JID | str, dict[tuple[int, int, str | None, str | None], Gdk.Texture]
 ]
+OccupantAvatarCacheT = dict[JID, dict[tuple[str, int, int], Gdk.Texture]]
 
 CIRCLE_RATIO = 0.18
 CIRCLE_FILL_RATIO = 0.80
@@ -61,7 +65,6 @@ def generate_avatar_letter(text: str) -> str:
 def generate_avatar(
     letters: str, color: tuple[float, float, float], size: int, scale: int
 ) -> cairo.ImageSurface:
-
     # Get color for nickname with XEP-0392
     color_r, color_g, color_b = color
 
@@ -112,7 +115,6 @@ def generate_default_avatar(
     scale: int,
     style: str = "circle",
 ) -> cairo.ImageSurface:
-
     surface = generate_avatar(letter, color, size, scale)
     surface = clip(surface, style)
     surface.set_device_scale(scale, scale)
@@ -127,7 +129,6 @@ def make_workspace_avatar(
     scale: int,
     style: str = "round-corners",
 ) -> Gdk.Texture:
-
     surface = generate_avatar(letter, color, size, scale)
     surface.set_device_scale(scale, scale)
     return convert_surface_to_texture(clip(surface, style))
@@ -137,7 +138,6 @@ def add_transport_to_avatar(
     surface: cairo.ImageSurface,
     transport_icon: str,
 ) -> cairo.ImageSurface:
-
     scale = surface.get_device_scale()[0]
     width = surface.get_width()
     height = surface.get_height()
@@ -181,7 +181,6 @@ def add_transport_to_avatar(
 
 
 def add_status_to_avatar(surface: cairo.ImageSurface, show: str) -> cairo.ImageSurface:
-
     width = surface.get_width()
     height = surface.get_height()
 
@@ -272,7 +271,6 @@ def merge_avatars(avatar1: Gdk.Texture, avatar2: Gdk.Texture) -> Gdk.Texture:
 def get_show_circle(
     show: str | types.PresenceShowT, size: int, scale: int
 ) -> cairo.ImageSurface:
-
     if not isinstance(show, str):
         show = show.value
 
@@ -403,9 +401,7 @@ def round_corners(surface: cairo.ImageSurface) -> cairo.ImageSurface:
 
     context.new_sub_path()
     context.arc(width - radius, radius, radius, -90 * degrees, 0 * degrees)
-    context.arc(
-        width - radius, height - radius, radius, 0 * degrees, 90 * degrees
-    )  # noqa: E501
+    context.arc(width - radius, height - radius, radius, 0 * degrees, 90 * degrees)  # noqa: E501
     context.arc(radius, height - radius, radius, 90 * degrees, 180 * degrees)
     context.arc(radius, radius, radius, 180 * degrees, 270 * degrees)
     context.close_path()
@@ -432,6 +428,7 @@ def convert_to_greyscale(surface: cairo.ImageSurface) -> cairo.ImageSurface:
 class AvatarStorage(metaclass=Singleton):
     def __init__(self):
         self._cache: AvatarCacheT = defaultdict(dict)
+        self._occupant_cache: OccupantAvatarCacheT = defaultdict(dict)
 
     def invalidate_cache(self, jid: JID | str) -> None:
         self._cache.pop(jid, None)
@@ -457,7 +454,6 @@ class AvatarStorage(metaclass=Singleton):
         transport_icon: str | None = None,
         style: str = "circle",
     ) -> Gdk.Texture:
-
         jid = contact.jid
 
         if not default:
@@ -465,7 +461,9 @@ class AvatarStorage(metaclass=Singleton):
             if texture is not None:
                 return texture
 
-            surface = self._get_avatar_from_storage(contact, size, scale, style)
+            surface = self._get_avatar_from_storage(
+                contact.avatar_sha, size, scale, style
+            )
             if surface is not None:
                 if show is not None:
                     surface = add_status_to_avatar(surface, show)
@@ -501,7 +499,6 @@ class AvatarStorage(metaclass=Singleton):
         transport_icon: str | None = None,
         style: str = "circle",
     ) -> Gdk.Texture:
-
         if not default:
             texture = self._cache[jid].get((size, scale, None, transport_icon))
             if texture is not None:
@@ -526,7 +523,9 @@ class AvatarStorage(metaclass=Singleton):
                 app.storage.cache.set_muc(account, jid, "avatar", None)
 
         client = app.get_client(account)
-        contact = client.get_module("Contacts").get_bare_contact(jid)
+        contact = client.get_module("Contacts").get_contact_if_exists(jid)
+        assert contact is not None
+        assert not isinstance(contact, ResourceContact)
 
         name = get_groupchat_name(client, jid)
         color = get_contact_color(contact)
@@ -539,10 +538,61 @@ class AvatarStorage(metaclass=Singleton):
         self._cache[jid][(size, scale, None, transport_icon)] = texture
         return texture
 
+    def get_occupant_texture(
+        self,
+        jid: JID,
+        occupant: mod.Occupant | str,
+        size: int,
+        scale: int,
+        style: str = "circle",
+    ) -> Gdk.Texture:
+        if isinstance(occupant, str):
+            key = occupant
+            nickname = occupant
+            avatar_sha = None
+            real_remote = None
+        else:
+            key = occupant.id
+            assert occupant.nickname is not None
+            nickname = occupant.nickname
+            avatar_sha = occupant.avatar_sha
+            real_remote = occupant.real_remote
+
+        texture = self._occupant_cache[jid].get((key, size, scale))
+        if texture is not None:
+            return texture
+
+        surface = self._get_avatar_from_storage(avatar_sha, size, scale, style)
+        if surface is not None:
+            texture = convert_surface_to_texture(surface)
+            self._occupant_cache[jid][(key, size, scale)] = texture
+            return texture
+
+        if real_remote is not None:
+            color = text_to_color(str(real_remote.jid))
+        else:
+            color = text_to_color(nickname)
+
+        letter = generate_avatar_letter(nickname)
+        surface = generate_default_avatar(letter, color, size, scale, style=style)
+
+        texture = convert_surface_to_texture(surface)
+        self._occupant_cache[jid][(key, size, scale)] = texture
+        return texture
+
+    def get_own_avatar_texture(
+        self, account: str, size: int, scale: int, add_show: bool = False
+    ) -> Gdk.Texture | None:
+        client = app.get_client(account)
+        self_contact = client.get_module("Contacts").get_contact(
+            client.get_own_jid().bare
+        )
+        assert isinstance(self_contact, BareContact)
+        return self_contact.get_avatar(size, scale, add_show=add_show)
+
     def get_workspace_texture(
         self, workspace_id: str, size: int, scale: int
     ) -> Gdk.Texture | None:
-
         texture = self._cache[workspace_id].get((size, scale, None, None))
         if texture is not None:
             return texture
@@ -691,7 +741,6 @@ class AvatarStorage(metaclass=Singleton):
     def surface_from_filename(
         self, filename: str, size: int, scale: int
     ) -> cairo.ImageSurface | None:
-
         size = size * scale
         path = self.get_avatar_path(filename)
         if path is None:
@@ -719,19 +768,15 @@ class AvatarStorage(metaclass=Singleton):
 
     def _get_avatar_from_storage(
         self,
-        contact: (
-            types.BareContact | types.GroupchatContact | types.GroupchatParticipant
-        ),
+        sha: str | None,
         size: int,
         scale: int,
         style: str,
     ) -> cairo.ImageSurface | None:
-
-        avatar_sha = contact.avatar_sha
-        if avatar_sha is None:
+        if sha is None:
             return None
 
-        surface = self.surface_from_filename(avatar_sha, size, scale)
+        surface = self.surface_from_filename(sha, size, scale)
         if surface is None:
             return None
         return clip(surface, style)
