@@ -40,14 +40,14 @@ from gajim.gtk.alert import CancelDialogResponse
 from gajim.gtk.alert import ConfirmationAlertDialog
 from gajim.gtk.alert import DialogResponse
 from gajim.gtk.builder import get_builder
-from gajim.gtk.contact_name_widget import ContactNameWidget
+from gajim.gtk.contact_name_entry import ContactNameEntry
 from gajim.gtk.contact_settings import ContactSettings
 from gajim.gtk.omemo_trust_manager import OMEMOTrustManager
 from gajim.gtk.sidebar_switcher import SideBarSwitcher
 from gajim.gtk.structs import AccountJidParam
 from gajim.gtk.util.misc import get_ui_string
 from gajim.gtk.vcard_grid import VCardGrid
-from gajim.gtk.widgets import GajimAppWindow
+from gajim.gtk.window import GajimAppWindow
 
 log = logging.getLogger("gajim.gtk.contact_info")
 
@@ -73,8 +73,6 @@ class ContactInfo(GajimAppWindow, EventHelper):
             title=_("Contact Information"),
             default_width=700,
             default_height=600,
-            add_window_padding=False,
-            header_bar=False,
         )
 
         EventHelper.__init__(self)
@@ -189,7 +187,6 @@ class ContactInfo(GajimAppWindow, EventHelper):
         self._client.disconnect_all_from_obj(self)
         self._disconnect_all()
         self.unregister_events()
-        app.check_finalize(self)
 
     def _on_client_state_changed(
         self, _client: types.Client, _signal_name: str, state: SimpleClientState
@@ -203,17 +200,15 @@ class ContactInfo(GajimAppWindow, EventHelper):
             self._ui.groups_page_stack.set_visible_child_name("offline")
             self._ui.notes_page_stack.set_visible_child_name("offline")
 
-    def _on_contact_name_updated(self, _widget: ContactNameWidget, name: str) -> None:
+    def _on_contact_name_updated(self, _widget: ContactNameEntry, name: str) -> None:
         self._sidebar_page.set_title(name)
 
     def _fill_information_page(self) -> None:
-        contact_name_widget = ContactNameWidget(
-            contact=self.contact, edit_mode=self._is_in_roster
+        contact_name_entry = ContactNameEntry(
+            contact=self.contact, editable=self._is_in_roster
         )
-        self._connect(
-            contact_name_widget, "name-updated", self._on_contact_name_updated
-        )
-        self._ui.contact_name_controls_box.append(contact_name_widget)
+        self._connect(contact_name_entry, "name-updated", self._on_contact_name_updated)
+        self._ui.contact_name_controls_box.append(contact_name_entry)
 
         self._vcard_grid = VCardGrid(self.account)
         self._ui.vcard_box.append(self._vcard_grid)
@@ -420,7 +415,7 @@ class ContactInfo(GajimAppWindow, EventHelper):
                     ),
                 ],
                 callback=_on_response,
-                parent=self.window,
+                parent=self,
             )
         return Gdk.EVENT_STOP
 
@@ -488,7 +483,7 @@ class ContactInfo(GajimAppWindow, EventHelper):
             confirm_label=_("_Remove"),
             appearance="destructive",
             callback=_on_response,
-            parent=self.window,
+            parent=self,
         )
         return Gdk.EVENT_STOP
 
