@@ -463,13 +463,25 @@ class ManageRoster(Gtk.Box, SignalManager, EventHelper):
         items: list[ImportedItem] = []
         with path.open(encoding="utf-8") as csvfile:
             reader = csv.reader(csvfile, strict=True)
-            for row in reader:
-                if row[CSVColumn.JID] in jids:
-                    continue
+            try:
+                for row in reader:
+                    if len(row) != 3:
+                        continue
 
-                item = self._validate_imported_item(row)
-                if item is not None:
-                    items.append(item)
+                    if row[CSVColumn.JID] in jids:
+                        continue
+
+                    item = self._validate_imported_item(row)
+                    if item is not None:
+                        items.append(item)
+            except Exception:
+                log.error("Could not read file %s to import roster contacts", path.name)
+                InformationAlertDialog(
+                    _("Import Error"),
+                    _("Could not read content of %s. Only CSV files can be imported.")
+                    % path.name,
+                )
+                return
 
         if not items:
             InformationAlertDialog(_("Import Error"), _("No contacts found to import"))
@@ -533,10 +545,12 @@ class ManageRoster(Gtk.Box, SignalManager, EventHelper):
         _n_press: int,
         x: float,
         y: float,
-    ) -> bool:
+    ) -> None:
+        gesture_click.set_state(Gtk.EventSequenceState.CLAIMED)
+
         items = self._get_selected_items()
         if not items:
-            return Gdk.EVENT_STOP
+            return
 
         single_selection = len(items) == 1
         groups = self._client.get_module("Roster").get_groups()
@@ -547,8 +561,6 @@ class ManageRoster(Gtk.Box, SignalManager, EventHelper):
         self._popover_menu.set_pointing_to_coord(x, y)
         self._popover_menu.popup()
 
-        return Gdk.EVENT_STOP
-
 
 class RosterListItem(GObject.Object):
     __gtype_name__ = "RosterListItem"
